@@ -158,7 +158,7 @@ weightedmean <- function(x,...){
 #' @param clabel label of the colour legend
 #' @param rect.col Fill colour for the measurements or age estimates. This can
 #'     either be a single colour or multiple colours to form a colour
-#'     ramp (to be used if \code{levels!=NA}):
+#'     ramp (to be used if \code{levels!=NULL}):
 #'
 #' a single colour: \code{rgb(0,1,0,0.5)}, \code{'#FF000080'},
 #' \code{'white'}, etc.;
@@ -210,7 +210,7 @@ weightedmean <- function(x,...){
 #' @export
 weightedmean.default <- function(x,from=NA,to=NA,random.effects=FALSE,
                                  detect.outliers=TRUE,plot=TRUE,
-                                 levels=NA,clabel="",
+                                 levels=NULL,clabel="",
                                  rect.col=c("#00FF0080","#FF000080"),
                                  outlier.col="#00FFFF80",sigdig=2,
                                  oerr=3,ranked=FALSE,hide=NULL,
@@ -244,7 +244,7 @@ weightedmean.default <- function(x,from=NA,to=NA,random.effects=FALSE,
 #' @export
 weightedmean.other <- function(x,from=NA,to=NA,random.effects=FALSE,
                                  detect.outliers=TRUE,plot=TRUE,
-                                 levels=NA,clabel="",
+                                 levels=NULL,clabel="",
                                  rect.col=c("#00FF0080","#FF000080"),
                                  outlier.col="#00FFFF80",sigdig=2,
                                  oerr=3,ranked=FALSE,hide=NULL,
@@ -313,7 +313,7 @@ weightedmean.other <- function(x,from=NA,to=NA,random.effects=FALSE,
 #' @export
 weightedmean.UPb <- function(x,random.effects=FALSE,
                              detect.outliers=TRUE,plot=TRUE,from=NA,
-                             to=NA,levels=NA,clabel="",
+                             to=NA,levels=NULL,clabel="",
                              rect.col=c("#00FF0080","#FF000080"),
                              outlier.col="#00FFFF80",sigdig=2,type=4,
                              cutoff.76=1100,oerr=3,cutoff.disc=discfilter(),
@@ -336,7 +336,7 @@ weightedmean.UPb <- function(x,random.effects=FALSE,
 #' @export
 weightedmean.PbPb <- function(x,random.effects=FALSE,
                               detect.outliers=TRUE,plot=TRUE, from=NA,
-                              to=NA,levels=NA,clabel="",
+                              to=NA,levels=NULL,clabel="",
                               rect.col=c("#00FF0080","#FF000080"),
                               outlier.col="#00FFFF80",sigdig=2,
                               oerr=3,exterr=FALSE,common.Pb=2,
@@ -387,7 +387,7 @@ weightedmean.PbPb <- function(x,random.effects=FALSE,
 #' @export
 weightedmean.ThU <- function(x,random.effects=FALSE,
                              detect.outliers=TRUE,plot=TRUE, from=NA,
-                             to=NA,levels=NA,clabel="",
+                             to=NA,levels=NULL,clabel="",
                              rect.col=c("#00FF0080","#FF000080"),
                              outlier.col="#00FFFF80",sigdig=2,
                              oerr=3,ranked=FALSE,Th0i=0,hide=NULL,
@@ -404,7 +404,7 @@ weightedmean.ThU <- function(x,random.effects=FALSE,
 #' @export
 weightedmean.ArAr <- function(x,random.effects=FALSE,
                               detect.outliers=TRUE,plot=TRUE, from=NA,
-                              to=NA,levels=NA,clabel="",
+                              to=NA,levels=NULL,clabel="",
                               rect.col=c("#00FF0080","#FF000080"),
                               outlier.col="#00FFFF80",sigdig=2,
                               oerr=3,exterr=FALSE,ranked=FALSE,i2i=FALSE,
@@ -421,7 +421,7 @@ weightedmean.ArAr <- function(x,random.effects=FALSE,
 #' @export
 weightedmean.KCa <- function(x,random.effects=FALSE,
                              detect.outliers=TRUE,plot=TRUE, from=NA,
-                             to=NA,levels=NA,clabel="",
+                             to=NA,levels=NULL,clabel="",
                              rect.col=c("#00FF0080","#FF000080"),
                              outlier.col="#00FFFF80",sigdig=2,
                              oerr=3,exterr=FALSE,ranked=FALSE,i2i=FALSE,
@@ -438,7 +438,7 @@ weightedmean.KCa <- function(x,random.effects=FALSE,
 #' @export
 weightedmean.ThPb <- function(x,random.effects=FALSE,
                               detect.outliers=TRUE,plot=TRUE, from=NA,
-                              to=NA,levels=NA,clabel="",
+                              to=NA,levels=NULL,clabel="",
                               rect.col=c("#00FF0080","#FF000080"),
                               outlier.col="#00FFFF80",sigdig=2,
                               oerr=3,exterr=FALSE,ranked=FALSE,i2i=TRUE,
@@ -455,7 +455,7 @@ weightedmean.ThPb <- function(x,random.effects=FALSE,
 #' @export
 weightedmean.ReOs <- function(x,random.effects=FALSE,
                               detect.outliers=TRUE,plot=TRUE, from=NA,
-                              to=NA,levels=NA,clabel="",
+                              to=NA,levels=NULL,clabel="",
                               rect.col=c("#00FF0080","#FF000080"),
                               outlier.col="#00FFFF80",sigdig=2,
                               oerr=3,exterr=FALSE,ranked=FALSE,i2i=TRUE,
@@ -472,7 +472,7 @@ weightedmean.ReOs <- function(x,random.effects=FALSE,
 #' @export
 weightedmean.SmNd <- function(x,random.effects=FALSE,
                               detect.outliers=TRUE,plot=TRUE,from=NA,
-                              to=NA,levels=NA,clabel="",
+                              to=NA,levels=NULL,clabel="",
                               rect.col=c("#00FF0080","#FF000080"),
                               outlier.col="#00FFFF80",sigdig=2,
                               oerr=3,exterr=FALSE,ranked=FALSE,
@@ -489,7 +489,7 @@ weightedmean.SmNd <- function(x,random.effects=FALSE,
 #' @export
 weightedmean.RbSr <- function(x,random.effects=FALSE,
                               detect.outliers=TRUE,plot=TRUE,from=NA,
-                              to=NA,levels=NA,clabel="",
+                              to=NA,levels=NULL,clabel="",
                               rect.col=c("#00FF0080","#FF000080"),
                               outlier.col="#00FFFF80",sigdig=2,
                               oerr=3,exterr=FALSE,i2i=TRUE,ranked=FALSE,
@@ -506,7 +506,7 @@ weightedmean.RbSr <- function(x,random.effects=FALSE,
 #' @export
 weightedmean.LuHf <- function(x,random.effects=FALSE,
                               detect.outliers=TRUE,plot=TRUE,
-                              from=NA,to=NA,levels=NA,clabel="",
+                              from=NA,to=NA,levels=NULL,clabel="",
                               rect.col=c("#00FF0080","#FF000080"),
                               outlier.col="#00FFFF80",sigdig=2,
                               oerr=3,exterr=FALSE,i2i=TRUE,ranked=FALSE,
@@ -523,7 +523,7 @@ weightedmean.LuHf <- function(x,random.effects=FALSE,
 #' @export
 weightedmean.UThHe <- function(x,random.effects=FALSE,
                                detect.outliers=TRUE,plot=TRUE,
-                               from=NA,to=NA,levels=NA,clabel="",
+                               from=NA,to=NA,levels=NULL,clabel="",
                                rect.col=c("#00FF0080","#FF000080"),
                                outlier.col="#00FFFF80",sigdig=2,
                                oerr=3,ranked=FALSE,hide=NULL,
@@ -540,7 +540,7 @@ weightedmean.UThHe <- function(x,random.effects=FALSE,
 #' @export
 weightedmean.fissiontracks <- function(x,random.effects=FALSE,
                                        detect.outliers=TRUE,plot=TRUE,
-                                       from=NA,to=NA,levels=NA,clabel="",
+                                       from=NA,to=NA,levels=NULL,clabel="",
                                        rect.col=c("#00FF0080","#FF000080"),
                                        outlier.col="#00FFFF80",
                                        sigdig=2,oerr=3,exterr=FALSE,ranked=FALSE,
@@ -555,7 +555,7 @@ weightedmean.fissiontracks <- function(x,random.effects=FALSE,
 }
 weightedmean_helper <- function(x,random.effects=FALSE,
                                 detect.outliers=TRUE,plot=TRUE,
-                                from=NA,to=NA,levels=NA,clabel="",
+                                from=NA,to=NA,levels=NULL,clabel="",
                                 rect.col=c("#00FF0080","#FF000080"),
                                 outlier.col="#00FFFF80",type=4,
                                 cutoff.76=1100,cutoff.disc=discfilter(),
@@ -648,7 +648,7 @@ get_weightedmean <- function(X,sX,random.effects=FALSE,valid=TRUE,oerr=1){
     out
 }
 
-plot_weightedmean <- function(X,sX,fit,from=NA,to=NA,levels=NA,clabel="",
+plot_weightedmean <- function(X,sX,fit,from=NA,to=NA,levels=NULL,clabel="",
                               rect.col=c("#00FF0080","#FF000080"),
                               outlier.col="#00FFFF80",sigdig=2,
                               oerr=3,units='',ranked=FALSE,hide=NULL,
